@@ -1,11 +1,9 @@
 
-import datetime
-import kraken_datatype as dt 
-from kraken_schema_org import kraken_schema_org as k
-from kraken_thing import json_xp as json
 import sys
 import uuid
-from kraken_thing import normalize_value as nv
+import datetime
+
+from kraken_thing.libraries import json_xp as json
 
 
 class Observation:
@@ -27,21 +25,24 @@ class Observation:
         self.normalized_value = None
         self.valid_value = False     # bool if value has been validated
         self.value = value
-        self.credibility = credibility
-        self.date = date
+
+        # Metadata
+        # Metadata
         self._source_observations_id = []  # The observation_ids used to generate this observations
+        self._object = None
+        self._agent = None
+        self._instrument = None
+        self._credibility = credibility
+        self._date = date
+
+
+        
         self.source_observations = []      # The actual observations (when available)
         self.child_observations = []       # the observations dependant on this one
-        self.instrument = None
         
         self.db_date = datetime.datetime.now()
 
-
-        # metadata
-        self.agent = None
-        self.instrument = None
-        self.object = None
-
+        # Assign
         self.key = key
         self.value = value
 
@@ -98,6 +99,11 @@ class Observation:
         '''
         '''
 
+        if not other:
+            return False
+        if not isinstance(other, Observation):
+            return False
+        
         if self.dump() == other.dump():
             return True
 
@@ -218,7 +224,7 @@ class Observation:
         '''
 
         record = {}
-        for k in self.keys():
+        for k in self.metadata_keys():
             record[k] = getattr(self, k)
 
         return record
@@ -235,7 +241,7 @@ class Observation:
         if not isinstance(value, dict):
             return
             
-        for k, v in value.keys():
+        for k, v in value.items():
             setattr(self, k, v)
 
         return
@@ -244,12 +250,12 @@ class Observation:
     def keys(self):
         '''
         '''
-        return [ 'key', 'valid_key', 'value', 'valid_value', 'source_observation', 'instrument', 'credibility', 'date']
+        return [ 'key', 'valid_key', 'value', 'valid_value', '_source_observations_id', '_object', '_agent', '_instrument', '_credibility', '_date']
 
     def metadata_keys(self):
         '''
         '''
-        return ['source_observation', 'instrument', 'credibility', 'date']
+        return ['_source_observations_id', '_object', '_agent', '_instrument', '_credibility', '_date']
 
         
     def load(self, record):
@@ -332,7 +338,14 @@ class Observation:
             if value not in self._source_observations_id:
                 self._source_observations_id.append(value)
 
+    @property
+    def credibility(self):
+        return self._credibility
 
+    @property
+    def date(self):
+        return self._date
+    
 
     
     '''Methods
